package command
import "github.com/edgexfoundry/go-mod-core-contracts/clients/command"
Package command provides a client for integration with the core-command service.
Index ¶
Types ¶
type CommandClient ¶
type CommandClient interface {
// Get issues a GET command targeting the specified device, using the specified command id
Get(ctx context.Context, deviceId string, commandId string) (string, error)
// Put issues a PUT command targeting the specified device, using the specified command id
Put(ctx context.Context, deviceId string, commandId string, body string) (string, error)
// GetDeviceCommandByNames issues a GET command targeting the specified device, using the specified device and command name
GetDeviceCommandByNames(ctx context.Context, deviceName string, commandName string) (string, error)
// PutDeviceCommandByNames issues a PUT command targeting the specified device, using the specified device and command names
PutDeviceCommandByNames(ctx context.Context, deviceName string, commandName string, body string) (string, error)
}
CommandClient interface defines interactions with the EdgeX Core Command microservice.
func NewCommandClient ¶
func NewCommandClient(urlClient interfaces.URLClient) CommandClient
NewCommandClient creates an instance of CommandClient
Source Files ¶
- Version
- v0.1.149 (latest)
- Published
- Jan 19, 2021
- Platform
- linux/amd64
- Imports
- 3 packages
- Last checked
- 1 year ago –
Tools for package owners.